# spec file for package rtaudio
#
# Copyright (c) 2017 Packman Team <packman@links2linux.de>
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#


%define soname  5
Name:           rtaudio
Version:        4.1.2
Release:        1.2
Summary:        Realtime Audio Input/Output Library
License:        MIT
Group:          System/Libraries
Url:            https://www.music.mcgill.ca/~gary/rtaudio/
Source:         https://www.music.mcgill.ca/~gary/rtaudio/release/rtaudio-%{version}.tar.gz
Source98:       baselibs.conf
# PATCH-FIX-OPENSUSE rtaudio-keep_your_compiler_flags_for_yourself.patch
Patch3:         rtaudio-keep_your_compiler_flags_for_yourself.patch
Patch4:         rtaudio.abs.patch
# PATCH-FIX-UPSTREAM rtaudio-fix_pyrtaudio.patch -- backported commits #bd5f15d and #e880888
Patch5:         rtaudio-fix_pyrtaudio.patch
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  jack-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
RtAudio is a set of C++ classes that provides a common API (Application
Programming Interface) for realtime audio input/output across Linux (native
ALSA, JACK, and OSS), Macintosh OS X, SGI, and Windows (DirectSound and ASIO)
operating systems.
RtAudio significantly simplifies the process of interacting with computer audio
hardware.

It was designed with the following objectives:
- object-oriented C++ design
- simple, common API across all supported platforms
- only one source and two header files for easy inclusion in programming
  projects
- allow simultaneous multi-api support
- support dynamic connection of devices
- provide extensive audio device parameter control
- allow audio device capability probing
- automatic internal conversion for data format, channel number compensation,
  (de)interleaving, and byte-swapping

RtAudio incorporates the concept of audio streams, which represent audio output
(playback) and/or input (recording).  Available audio devices and their
capabilities can be enumerated and then specified when opening a stream.  Where
applicable, multiple API support can be compiled and a particular API specified
when creating an RtAudio instance.

%package -n librtaudio%{soname}
Summary:        Realtime Audio Input/Output Library
Group:          System/Libraries

%description -n librtaudio%{soname}
RtAudio is a set of C++ classes that provides a common API (Application
Programming Interface) for realtime audio input/output across Linux (native
ALSA, JACK, and OSS), Macintosh OS X, SGI, and Windows (DirectSound and ASIO)
operating systems.
RtAudio significantly simplifies the process of interacting with computer audio
hardware.

It was designed with the following objectives:
- object-oriented C++ design
- simple, common API across all supported platforms
- only one source and two header files for easy inclusion in programming
  projects
- allow simultaneous multi-api support
- support dynamic connection of devices
- provide extensive audio device parameter control
- allow audio device capability probing
- automatic internal conversion for data format, channel number compensation,
  (de)interleaving, and byte-swapping

RtAudio incorporates the concept of audio streams, which represent audio output
(playback) and/or input (recording).  Available audio devices and their
capabilities can be enumerated and then specified when opening a stream.  Where
applicable, multiple API support can be compiled and a particular API specified
when creating an RtAudio instance.

%package devel
Summary:        Realtime Audio Input/Output Library
Group:          Development/Libraries/C and C++
Requires:       librtaudio%{soname} = %{version}

%description devel
RtAudio is a set of C++ classes that provides a common API (Application
Programming Interface) for realtime audio input/output across Linux (native
ALSA, JACK, and OSS), Macintosh OS X, SGI, and Windows (DirectSound and ASIO)
operating systems.
RtAudio significantly simplifies the process of interacting with computer audio
hardware.

It was designed with the following objectives:
- object-oriented C++ design
- simple, common API across all supported platforms
- only one source and two header files for easy inclusion in programming
  projects
- allow simultaneous multi-api support
- support dynamic connection of devices
- provide extensive audio device parameter control
- allow audio device capability probing
- automatic internal conversion for data format, channel number compensation,
  (de)interleaving, and byte-swapping

RtAudio incorporates the concept of audio streams, which represent audio output
(playback) and/or input (recording).  Available audio devices and their
capabilities can be enumerated and then specified when opening a stream.  Where
applicable, multiple API support can be compiled and a particular API specified
when creating an RtAudio instance.

%package -n python-rtaudio
Summary:        Realtime Audio Input/Output Library for Python
Group:          Development/Libraries/Python
# does _NOT_ require the shlib package

%description -n python-rtaudio
RtAudio is a set of C++ classes that provides a common API (Application
Programming Interface) for realtime audio input/output across Linux (native
ALSA, JACK, and OSS), Macintosh OS X, SGI, and Windows (DirectSound and ASIO)
operating systems.
RtAudio significantly simplifies the process of interacting with computer audio
hardware.

This package provides Python bindings to rtaudio.

%prep
%setup -q
%patch3 -p1
%patch4 -p1
%patch5 -p1
chmod -x readme

%build
%configure \
    --disable-static \
    --with-jack \
    --with-alsa
make %{?_smp_mflags}

B="$PWD"
pushd "contrib/python/pyrtaudio"
CFLAGS="-I$B/include -fno-strict-aliasing" \
python ./setup.py build
popd

%install
%make_install
install -D -m0755 rtaudio-config "%{buildroot}%{_bindir}/rtaudio-config"
find %{buildroot} -name *.la -delete

B="$PWD"
pushd "contrib/python/pyrtaudio"
python ./setup.py install \
    --root=%{buildroot} \
    --prefix="%{_prefix}" \
    --record-rpm="$B/.pyfiles.lst"
popd

%post   -n librtaudio%{soname} -p /sbin/ldconfig
%postun -n librtaudio%{soname} -p /sbin/ldconfig

%files -n librtaudio%{soname}
%defattr(-,root,root)
%doc readme
%{_libdir}/librtaudio.so.%{soname}*

%files devel
%defattr(-,root,root)
%{_bindir}/rtaudio-config
%{_includedir}/rtaudio
%{_libdir}/librtaudio.so
%{_libdir}/pkgconfig/rtaudio.pc

%files -n python-rtaudio -f .pyfiles.lst
%defattr(-,root,root)

%changelog
* Thu Jun 15 2017 aloisio@gmx.com
- Update to version 4.1.2
  * added more complete automake support (thanks to Stephen
    Sinclair)
  * miscellaneous small fixes and updates, see github repo commit
    history for details
  4.1.1: (26 April 2014)
  * updates to WASAPI API for MinGW compiling
  * WASAPI bug fixes for audio INPUT mode
  * DirectSound bug fix for INPUT mode
  * Bug fixes in Core, Jack, ASIO and DS for internal draining in
    INPUT mode
  * updates to test programs for default device specifiers
  * CMake buildfile update for WASAPI
  * new setStreamTime function
  v4.1.0: (10 April 2014)
  * RtError class renamed RtAudioError and embedded in RtAudio.h
    (RtError.h deleted)
  * new support for the Windows WASAPI API (thanks to Marcus
    Tomlinson)
  * CMake support (thanks to Berkus Decker)
  * pulse audio update to support bufferFrames argument with audio
    input (thanks to Jonatan Wallmander)
  * fixes for ALSA API to avoid high CPU usage during stops and to
    clear stale data before input (thanks to Pluto Hades)
  * miscellaneous efficiency updates suggested by Martin Koegler
  * bug fix for OS-X xrun reporting problem
  * bug fix related to error when opening a stream after closing a
    previously open stream
  v4.0.12: (16 April 2013)
  * new functionality to allow error reporting via a
    client-supplied function (thanks to Pavel Mogilevskiy)
  * new function to return the version number
  * updated RtAudio.cpp and ASIO files for UNICODE support (thanks
    to Renaud Schoonbroodt)
  * updates to PulseAudio API support (thanks to Peter Meerwald
    and Tristan Matthews)
  * updates for pkg-config support in configure script
  * 24-bit format changed to true 24-bit format, not sub-bytes of
    32-bits (thanks to Marc Britton)
  * bug fixes to make sure stream status is closed if error during
    probeDeviceOpen
  * updates / fixes to SCHED_RR code in ALSA (thanks to Marc
    Lindahl)
  * various changes to avoid global variables (thanks to Martin
    Koegler)
  v4.0.11: (14 June 2012)
  * fixes for memory leaks in ALSA (thanks to Martin Koegler)
  * PulseAudio API support added (thanks to Peter Meerwald and
    Tristan Matthews)
  * bitwise format flag fixes in OS-X (Benjamin Schroeder and
    Stefan Arisona)
  * changes to stopStream / drain flag to avoid hung state in
    ASIO, DS, OS-X, and Jack APIs (Rasmus Ekman and Carlos Luna)
- Dropped rtaudio-fix_version.patch and rtaudio-optflags.patch
- Refreshed rtaudio-keep_your_compiler_flags_for_yourself.patch
- Added rtaudio-fix_pyrtaudio.patch
- Bumped SOVERSION to 5
- Disabled OSS (no longer fully supported upstream for linux)
- Build and ship only the shared library
* Sat Apr 21 2012 pascal.bleser@opensuse.org
- initial version (4.0.10)
